@@ -1,5 +1,5 @@
 #
-# $Id: Base64.pm,v 2.9 1998/10/21 13:01:08 aas Exp $
+# $Id: Base64.pm,v 2.12 1998/11/13 22:04:00 aas Exp $
 
 package MIME::Base64;
 
@@ -41,8 +41,15 @@ broken into lines.
 
 Decode a base64 string by calling the decode_base64() function.  This
 function takes a single argument which is the string to decode and
-returns the decoded data.  Any character not part of the legal Base64
-character set is ignored.
+returns the decoded data.
+
+Any character not part of the 65-character base64 subset set is
+silently ignored.  Characters occuring after a '=' padding character
+are never decoded.
+
+If the length of the string to decode (after ignoring
+non-base64 chars) is not a multiple of 4 or padding occurs too ealy,
+then a warning is generated if perl is running under C<-w>.
 
 =back
 
@@ -53,6 +60,27 @@ call them as:
     $encoded = MIME::Base64::encode($decoded);
     $decoded = MIME::Base64::decode($encoded);
 
+=head1 DIAGNOSTICS
+
+The following warnings might be generated if perl is invoked with the
+C<-w> switch:
+
+=over 4
+
+=item Premature end of base64 data
+
+The number of characters to decode is not a multiple of 4.  Legal
+base64 data should be padded with one or two "=" characters to make
+its length a multiple of 4.  The decoded result will anyway be as if
+the padding was there.
+
+=item Premature padding of base64 data
+
+The '=' padding character occurs as the first or second character
+in a base64 quartet.
+
+=back
+
 =head1 EXAMPLES
 
 If you want to encode a large file, you should encode it in chunks
@@ -98,7 +126,7 @@ require DynaLoader;
 @ISA = qw(Exporter DynaLoader);
 @EXPORT = qw(encode_base64 decode_base64);
 
-$VERSION = '2.07';
+$VERSION = '2.09';
 
 eval { bootstrap MIME::Base64 $VERSION; };
 if ($@) {
